Index: src/arm/lithium-codegen-arm.cc |
diff --git a/src/arm/lithium-codegen-arm.cc b/src/arm/lithium-codegen-arm.cc |
index d813c81f14652604108f8437010abef604d93455..3c845cba296438883f75633af7084410e9528df4 100644 |
--- a/src/arm/lithium-codegen-arm.cc |
+++ b/src/arm/lithium-codegen-arm.cc |
@@ -113,7 +113,7 @@ |
// r1: Callee's JS function. |
// cp: Callee's context. |
// pp: Callee's constant pool pointer (if enabled) |
// fp: Caller's frame pointer. |
// lr: Caller's pc. |
@@ -1009,6 +1009,10 @@ |
} else if (pointer->IsRegister() && (kind & Safepoint::kWithRegisters)) { |
safepoint.DefinePointerRegister(ToRegister(pointer), zone()); |
} |
+ } |
+ if (FLAG_enable_ool_constant_pool && (kind & Safepoint::kWithRegisters)) { |
+ // Register pp always contains a pointer to the constant pool. |
+ safepoint.DefinePointerRegister(pp, zone()); |
} |
} |
@@ -113,7 +113,7 @@ |
// r1: Callee's JS function. |
// cp: Callee's context. |
- // pp: Callee's constant pool pointer (if enabled) |
+ // pp: Callee's constant pool pointer (if FLAG_enable_ool_constant_pool) |
// fp: Caller's frame pointer. |
// lr: Caller's pc. |